@@ -347,7 +347,7 @@ impl Rpc {
     }
 
     fn transaction_broadcast(&self, (tx_hex,): &(String,)) -> Result<Value> {
-        let tx_bytes = Vec::from_hex(&tx_hex).context("non-hex transaction")?;
+        let tx_bytes = Vec::from_hex(tx_hex).context("non-hex transaction")?;
         let tx = deserialize(&tx_bytes).context("invalid transaction")?;
         let txid = self.daemon.broadcast(&tx)?;
         Ok(json!(txid))
@@ -356,18 +356,26 @@ impl Rpc {
     fn transaction_get(&self, args: &TxGetArgs) -> Result<Value> {
         let (txid, verbose) = args.into();
         if verbose {
-            let blockhash = self.tracker.get_blockhash_by_txid(txid);
+            let blockhash = self
+                .tracker
+                .lookup_transaction(&self.daemon, txid)?
+                .map(|(blockhash, _tx)| blockhash);
             return self.daemon.get_transaction_info(&txid, blockhash);
         }
-        let cached = self.cache.get_tx(&txid, |tx| serialize(tx).to_hex());
-        Ok(match cached {
-            Some(tx_hex) => json!(tx_hex),
-            None => {
-                debug!("tx cache miss: txid={}", txid);
-                let blockhash = self.tracker.get_blockhash_by_txid(txid);
-                json!(self.daemon.get_transaction_hex(&txid, blockhash)?)
-            }
-        })
+        if let Some(tx) = self.cache.get_tx(&txid, |tx| serialize(tx)) {
+            return Ok(json!(tx.to_hex()));
+        }
+        debug!("tx cache miss: txid={}", txid);
+        // use internal index to load confirmed transaction without an RPC
+        if let Some(tx) = self
+            .tracker
+            .lookup_transaction(&self.daemon, txid)?
+            .map(|(_blockhash, tx)| tx)
+        {
+            return Ok(json!(serialize(&tx).to_hex()));
+        }
+        // load unconfirmed transaction via RPC
+        Ok(json!(self.daemon.get_transaction_hex(&txid, None)?))
     }
 
     fn transaction_get_merkle(&self, (txid, height): &(Txid, usize)) -> Result<Value> {
@@ -427,17 +435,13 @@ impl Rpc {
     }
 
     pub fn handle_requests(&self, client: &mut Client, lines: &[String]) -> Vec<String> {
-        let parsed: Vec<Result<Calls, Value>> = lines
+        lines
             .iter()
             .map(|line| {
-                parse_requests(&line)
+                parse_requests(line)
                     .map(Calls::parse)
                     .map_err(error_msg_no_id)
             })
-            .collect();
-
-        parsed
-            .into_iter()
             .map(|calls| self.handle_calls(client, calls).to_string())
             .collect()
     }
